@@ -57,6 +57,12 @@ aggregateCovariates <- function(covariateData) {
   attr(class(result), "package") <- "FeatureExtraction"
   populationSize <- attr(covariateData, "metaData")$populationSize
 
+  # tmp rename rowId var
+  andromedaVersion <- utils::packageVersion("Andromeda")
+  if (andromedaVersion >= "1.0.0") {
+    covariateData$covariates <- covariateData$covariates %>% dplyr::rename(rowIdTemp = .data$rowId)
+  }
+
   # Aggregate binary variables
   result$covariates <- covariateData$analysisRef %>%
     filter(local(rlang::sym("isBinary")) == "Y") %>%
@@ -128,6 +134,12 @@ aggregateCovariates <- function(covariateData) {
   if (nrow(covariatesContinuous) > 0) {
     result$covariatesContinuous <- covariatesContinuous
   }
+
+  # revert tmp change
+  if (andromedaVersion >= "1.0.0") {
+    covariateData$covariates <- covariateData$covariates %>% dplyr::rename(rowId = .data$rowIdTemp)
+  }
+
   delta <- Sys.time() - start
   writeLines(paste("Aggregating covariates took", signif(delta, 3), attr(delta, "units")))
   return(result)
