@@ -29,7 +29,8 @@
 NULL
 
 .onLoad <- function(libname, pkgname) {
-  rJava::.jpackage(pkgname, lib.loc = libname)
+  params <- c(getOption("java.parameters"), "-XX:+UseAllWindowsProcessorGroups")
+  rJava::.jpackage(pkgname, lib.loc = libname, parameters = params)
 
   # Verify checksum of JAR:
   storedChecksum <- scan(file = system.file("csv", "jarChecksum.txt", package = "FeatureExtraction"), what = character(), quiet = TRUE)
